@@ -313,7 +313,8 @@ Mojo::Message - HTTP message base class
 =head1 DESCRIPTION
 
 L<Mojo::Message> is an abstract base class for HTTP messages based on
-L<RFC 2616|http://tools.ietf.org/html/rfc2616> as well as
+L<RFC 7230|http://tools.ietf.org/html/rfc7230>,
+L<RFC 7231|http://tools.ietf.org/html/rfc7231> and
 L<RFC 2388|http://tools.ietf.org/html/rfc2388>.
 
 =head1 EVENTS
@@ -498,7 +499,8 @@ make sure it is not excessively large, there's a 10MB limit by default.
   my $err = $msg->error;
   $msg    = $msg->error({message => 'Parser error', advice => 500});
 
-Message error.
+Get or set message error, an C<undef> return value indicates that there is no
+error.
 
 =head2 extract_start_line
 
